package com.zeus.core.demo;

import android.Manifest;
import android.app.Activity;
import android.content.Intent;
import android.content.pm.PackageManager;
import android.content.res.Configuration;
import android.os.Build;
import android.os.Bundle;
import android.support.annotation.NonNull;
import android.text.TextUtils;
import android.util.Log;
import android.view.KeyEvent;
import android.view.View;
import android.widget.TextView;
import android.widget.Toast;

import com.zeus.cdkey.api.OnUseCdKeyListener;
import com.zeus.core.api.ZeusPlatform;
import com.zeus.core.api.base.OnRewardCallback;
import com.zeus.log.api.LogUtils;
import com.zeus.pay.api.OnPayListener;
import com.zeus.pay.api.OnQueryPayOrderListener;
import com.zeus.pay.api.entity.PayOrderInfo;
import com.zeus.pay.api.entity.PayParams;
import com.zeus.policy.api.OnPrivacyPolicyListener;
import com.zeus.realname.api.IZeusRealNameCertification;
import com.zeus.realname.api.OnRealNameCertificationListener;
import com.zeus.realname.api.ZeusRealNameCertification;
import com.zeus.user.api.OnLoginListener;
import com.zeus.user.api.entity.ExtraPlayerInfo;
import com.zeus.user.api.entity.UserInfo;

import java.util.List;


public class MainActivity extends Activity {
    private static final String TAG = MainActivity.class.getName();
    private TextView mResultView;
    private CdKeyDialog mCdKeyDialog;

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        mResultView = findViewById(R.id.result_view);
        mResultView.setText("");

        // 如果游戏需要在启动时就动态申请权限，可在初始化前调用此接口，
        // SDK会统一在调初始化时申请一次权限，权限的申请结果可通过onRequestPermissionsResult知道，requestCode为ZeusCode.PERMISSION_REQUEST_CODE
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
            if (checkSelfPermission(Manifest.permission.WRITE_EXTERNAL_STORAGE) != PackageManager.PERMISSION_GRANTED) {
                //没有此权限
                ZeusPlatform.getInstance().addPermission(Manifest.permission.WRITE_EXTERNAL_STORAGE);
            }
        }

        // 云步SDK初始化
        ZeusPlatform.getInstance().init(this);

        //进入游戏后，在适当的时候，调用验证掉单接口，查询是否存在掉单的订单
        queryPayOrderInfo();
    }

    public void getZeusSdkVersion(View v) {
        int sdkVersion = ZeusPlatform.getInstance().getZeusSdkVersionCode();
        mResultView.setText("SDK版本:" + sdkVersion);
    }

    @Override
    public boolean onKeyDown(int keyCode, KeyEvent event) {
        Log.d(TAG, "OnKeyDown:" + keyCode);
        if (keyCode == KeyEvent.KEYCODE_BACK) {
            exitGame();
        }
        return true;
    }

    /**
     * 弹出游戏退出确认框（必接）
     */
    public void exitGame() {
        ZeusPlatform.getInstance().exitGame();
    }

    private OnLoginListener mOnLoginListener = new OnLoginListener() {
        @Override
        public void onLoginSuccess(UserInfo userInfo) {
            Log.d(TAG, "onLoginSuccess: " + userInfo);

            mResultView.setText("onLoginSuccess: " + userInfo);
        }

        @Override
        public void onLoginFailed(int code, String msg) {
            Log.e(TAG, "onLoginFailed: code=" + code + ",msg=" + msg);

            mResultView.setText("onLoginFailed: code=" + code + ",msg=" + msg);
        }
    };

    /**
     * 登录渠道(单机游戏选接)
     */
    public void login(View v) {
        ZeusPlatform.getInstance().login(this, mOnLoginListener);
    }

    /**
     * 当登录的是游客账号时，判断是否支持进行渠道账号绑定
     */
    public void isSupportBindAccount(View v) {
        boolean b = ZeusPlatform.getInstance().isSupportBindAccount();
        mResultView.setText("是否支持绑定渠道账号：" + b);
    }

    /**
     * 当登录的是游客账号时，先判断是否支持绑定渠道账号，如果支持，可调此方法进行渠道账号绑定，
     */
    public void bindAccount(View v) {
        ZeusPlatform.getInstance().bindAccount(this, mOnLoginListener);
    }

    /**
     * 提交游戏角色参数(单机游戏不需要接)
     */
    public void submitPlayerInfo(View v) {
        submitPlayerInfo(ExtraPlayerInfo.TYPE_CREATE_ROLE);
    }

    private void submitPlayerInfo(int type) {
        ExtraPlayerInfo playerInfo = new ExtraPlayerInfo();
        //在一下几个场景调用
        //1.选择服务器：ExtraPlayerInfo.TYPE_SELECT_SERVER
        //2.创建角色：ExtraPlayerInfo.TYPE_CREATE_ROLE
        //3.进入游戏：ExtraPlayerInfo.TYPE_ENTER_GAME
        //4.等级提升：ExtraPlayerInfo.TYPE_LEVEL_UP
        //5.退出游戏：ExtraPlayerInfo.TYPE_EXIT_GAME
        playerInfo.setType(type);
        //当前角色身上拥有的游戏币数量
        playerInfo.setCoinNum(100);
        //单位是秒，此处是参考，请传真实的角色创建时间，并且每次传递的值固定，建议从游戏服务器获取真实的角色创建时间，不能传随机值或当前系统时间值
        long roleCreateTime = System.currentTimeMillis() / 1000;
        playerInfo.setRoleCreateTime(roleCreateTime);
        //角色id
        playerInfo.setRoleId("role_100");
        //角色名称
        playerInfo.setRoleName("test_112");
        //角色等级
        playerInfo.setRoleLevel("10");
        //服务器id
        playerInfo.setServerId("10");
        //服务器名称
        playerInfo.setServerName("server_10");
        //VIP等级
        playerInfo.setVip("vip1");
        ZeusPlatform.getInstance().submitPlayerInfo(playerInfo);
    }

    private OnPayListener mOnPayListener = new OnPayListener() {
        @Override
        public void onPaySuccess(PayOrderInfo payOrderInfo) {
            Log.d(TAG, "onPaySuccess: " + payOrderInfo);
            Toast.makeText(MainActivity.this, "支付成功 ---- Demo提示,请修改", Toast.LENGTH_LONG).show();

            ZeusPlatform.getInstance().gameReceivePaySuccess(payOrderInfo);
            //执行发货逻辑
            LogUtils.d(TAG, "[onPaySuccess] 模拟游戏发货");
            //确认游戏收到发货
            LogUtils.d(TAG, "[onPaySuccess] 模拟玩家收到发货");
            //玩家收到发货后确认游戏调用核销订单接口
            ZeusPlatform.getInstance().reportOrderComplete(payOrderInfo, false);
        }

        @Override
        public void onPayCancel() {
            Log.d(TAG, "onPayCancel: ");
            Toast.makeText(MainActivity.this, "支付取消 ---- Demo提示,请修改", Toast.LENGTH_LONG).show();
        }

        @Override
        public void onPayFailed(int code, String msg) {
            Log.e(TAG, "onPayFailed: code=" + code + ",msg=" + msg);
            Toast.makeText(MainActivity.this, "支付失败 ---- Demo提示,请修改", Toast.LENGTH_LONG).show();
        }
    };

    /**
     * 游戏内购（必接）
     */
    public void pay(View v) {
        PayParams params = new PayParams();

        // 充值金额(默认单位：元)（必须）
        params.setPrice(1);

        // 金额单位，不设置默认为PayParams.UNIT.RMB_YUAN （可选）
        params.setUnit(PayParams.UNIT.RMB_YUAN);

        // 充值商品id，productId必须是数字，且必须是1、2、3、4、5......（必须）
        params.setProductId("1");

        // 商品名称，比如：100元宝，500钻石，不可包含特殊字符，只能包含中文、英文字母大小写、数字、下划线。（必须）
        params.setProductName("会员");

        // 商品描述，比如：充值100元宝，赠送20元宝，不可包含特殊字符，只能包含中文、英文字母大小写、数字、下划线。（必须）
        params.setProductDesc("会员");

        // 商品分类（可选）
        params.setProductCategory("no_ad");

        // 支付场景，如：关卡内
        params.setPayScene("level_10");

        // 透传参数，充值成功，回调通知游戏服务器的时候，会原封不动返回。（透传字段长度不超过64）（网游可选，单机不用传）
        //params.setDeveloperPayload("developerPayload");

        // 服务器发货模式的订单标识，订单ID要包含支付的信息，订单id长度不能超过30个字符，不可重复，且只能由字母大小写和数字组成，字母区分大小写（网游必须，单机不用传）
        //params.setOrderId("27858045183");

        ZeusPlatform.getInstance().pay(this, params, mOnPayListener);
    }

    /**
     * 查询是否存在已支付成功，但是未发货的订单（单机游戏必接）
     */
    public void queryPayOrderInfo() {
        ZeusPlatform.getInstance().queryPayOrderInfo(new OnQueryPayOrderListener() {
            @Override
            public void onQuerySuccess(List<PayOrderInfo> list) {
                //验证成功，根据PayOrderInfo中的商品id补发游戏道具
                mResultView.setText("掉单验证成功：" + list);
                for (PayOrderInfo payOrderInfo : list) {
                    //执行发货逻辑
                    LogUtils.d(TAG, "[onQuerySuccess] 模拟游戏发货");
                    //确认游戏收到发货
                    LogUtils.d(TAG, "[onQuerySuccess] 模拟玩家收到发货");
                    //玩家收到发货后调用核销订单接口
                    ZeusPlatform.getInstance().reportOrderComplete(payOrderInfo, true);
                }
            }

            @Override
            public void onQueryFailed(int code, String msg) {
                mResultView.setText("未查询到掉单");
            }
        });
    }

    /**
     * 获取自定义参数
     */
    public void showCustom(View v) {
        String customParam = ZeusPlatform.getInstance().getCustomParam();
        if (TextUtils.isEmpty(customParam)) {
            mResultView.setText("");
        } else {
            mResultView.setText(customParam);
        }
    }

    /**
     * 判断是否显示评价入口，true显示，false隐藏
     */
    public void showMarket(View v) {
        boolean showMarket = ZeusPlatform.getInstance().getSwitchState("showMarket");
        mResultView.setText("Show Market:" + showMarket);
    }

    /**
     * 五星好评引导，跳转应用商店游戏详情页
     */
    public void gotoMarket(View v) {
        ZeusPlatform.getInstance().gotoMarket(new OnRewardCallback() {
            @Override
            public void onReward(String productId) {
                //收到回调，根据商品id发放奖励，目前productId返回null，未定义发放奖励，游戏根据情况发放奖励商品
                Log.d(TAG, "goto market reward.");
            }
        });
    }

    /**
     * 打开游戏社区
     */
    public void gameForum(View v) {
        ZeusPlatform.getInstance().gameForum();
    }

    /**
     * 调起游戏互推界面
     */
    public void gameRecommend(View v) {
        ZeusPlatform.getInstance().gameRecommend();
    }

    /**
     * 调起休闲游戏专区
     *
     * @param v
     */
    public void leisureGameSubject(View v) {
        ZeusPlatform.getInstance().leisureGameSubject();
    }

    /**
     * 使用兑换码
     */
    public void useCdKey(View v) {
        if (mCdKeyDialog == null) {
            mCdKeyDialog = new CdKeyDialog(this);
        }
        mCdKeyDialog.show();
    }

    public void showUseCdKey(View v) {
        ZeusPlatform.getInstance().showCdKeyCenter(this, new OnUseCdKeyListener() {
            @Override
            public void onSuccess(String result) {
                //兑换成功，根据商品id发放商品
                Toast.makeText(MainActivity.this, "兑换成功：" + result, Toast.LENGTH_SHORT).show();
            }

            @Override
            public void onFailed(int code, String msg) {
                Toast.makeText(MainActivity.this, "兑换失败：" + msg, Toast.LENGTH_SHORT).show();
            }
        });
    }

    /**
     * 跳转QQ聊天
     */
    public void skipQQChat(View v) {
        ZeusPlatform.getInstance().skipQQChat("");
    }

    /**
     * 添加QQ群
     */
    public void joinQQGroup(View v) {
        ZeusPlatform.getInstance().joinQQGroup("");
    }

    /**
     * 跳转微信
     *
     * @param v
     */
    public void skipWeiChat(View v) {
        ZeusPlatform.getInstance().skipWeiChat("yunbugame");
    }

    /**
     * 调起拨号盘
     */
    public void callPhone(View v) {
        ZeusPlatform.getInstance().callPhone("123456");
    }

    /**
     * 分享
     *
     * @param v
     */
    public void share(View v) {
        ZeusPlatform.getInstance().share("分享的内容", new OnRewardCallback() {
            @Override
            public void onReward(String productId) {
                //收到回调，根据商品id发放奖励，目前productId返回null，未定义发放奖励，游戏根据情况发放奖励商品
                Log.d(TAG, "share reward.");
            }
        });
    }

    /**
     * 统计模块接口
     */
    public void analyticsTest(View v) {
        Intent intent = new Intent(this, ZeusAnalyticsActivity.class);
        startActivity(intent);
    }

    public void showPrivacyPolicy(View v) {
        ZeusPlatform.getInstance().showPrivacyPolicy(this, new OnPrivacyPolicyListener() {
            @Override
            public void onAccept() {

            }

            @Override
            public void onRefuse() {

            }
        });
    }

    public void showUserProtocolDetail(View v) {
        ZeusPlatform.getInstance().showUserProtocolDetail(this);
    }

    public void showPrivacyPolicyDetail(View v) {
        ZeusPlatform.getInstance().showPrivacyPolicyDetail(this);
    }

    public void isSupportRealNameCertification(View v) {
        boolean isSupportRealNameCertification = ZeusRealNameCertification.getInstance().isSupportRealNameCertification();
        mResultView.setText("是否支持实名认证:" + isSupportRealNameCertification);
    }

    public void isRealNameCertification(View v) {
        boolean realNameCertification = ZeusRealNameCertification.getInstance().isRealNameCertification();
        mResultView.setText("是否已实名认证:" + realNameCertification);
    }

    /**
     * 实名认证
     */
    public void realNameCertification(View v) {
        ZeusRealNameCertification.getInstance().realNameCertification(new OnRealNameCertificationListener() {
            @Override
            public void onCertificationSuccess(int age) {
                Log.d(TAG, "onCertificationSuccess: " + age);
            }

            @Override
            public void onCertificationFailed(int code) {
                Log.d(TAG, "onCertificationFailed: ");
                if (code == IZeusRealNameCertification.CERTIFICATION_FAILED) {
                    //实名认证失败
                } else if (code == IZeusRealNameCertification.NOT_SUPPORT) {
                    //不支持实名认证
                }
            }
        });
    }

    public void setExitGameTipsText(View v) {
        ZeusPlatform.getInstance().setExitGameTipsText("确定退出游戏吗？");
    }

    // ******** 生命周期函数接入 Start，重点！！！重点！！！重点！！！，必须接入以下所有的生命周期接口******* //
    @Override
    public void onStart() {
        super.onStart();
        ZeusPlatform.Lifecycle.onStart();
    }

    @Override
    public void onRestart() {
        super.onRestart();
        ZeusPlatform.Lifecycle.onRestart();
    }

    @Override
    public void onResume() {
        super.onResume();
        ZeusPlatform.Lifecycle.onResume();
    }

    @Override
    public void onPause() {
        super.onPause();
        ZeusPlatform.Lifecycle.onPause();
    }

    @Override
    public void onStop() {
        super.onStop();
        ZeusPlatform.Lifecycle.onStop();
    }

    @Override
    public void onDestroy() {
        super.onDestroy();
        ZeusPlatform.Lifecycle.onDestroy();
    }

    @Override
    public void onNewIntent(Intent newIntent) {
        super.onNewIntent(newIntent);
        ZeusPlatform.Lifecycle.onNewIntent(newIntent);
    }

    @Override
    public void onActivityResult(int requestCode, int resultCode, Intent data) {
        super.onActivityResult(requestCode, resultCode, data);
        ZeusPlatform.Lifecycle.onActivityResult(requestCode, resultCode, data);
    }

    @Override
    public void onConfigurationChanged(@NonNull Configuration newConfig) {
        super.onConfigurationChanged(newConfig);
        ZeusPlatform.Lifecycle.onConfigurationChanged(newConfig);
    }

    @Override
    public void onRequestPermissionsResult(int requestCode, @NonNull String[] permissions, @NonNull int[] grantResults) {
        ZeusPlatform.Lifecycle.onRequestPermissionsResult(requestCode, permissions, grantResults);
    }
    // ********************************** 生命周期函数接入 End *********************************** //
}
